F64116045 opened a new pull request, #11592: URL: https://github.com/apache/ozone/pull/11592
## What changes were proposed in this pull request? The test sleeps for 5 seconds before and after `processAll()`. This PR waits until ReplicationManager is ready instead of sleeping before the call. Also `processAll()` finishes processing before it returns, so the second sleep is also unnecessary. ## What is the link to the Apache JIRA https://issues.apache.org/jira/browse/HDDS-17091 ## How was this patch tested? | | Average | Median | | --- | ---: | ---: | | Before | 42.60 s | 43.68 s | | After | 33.86 s | 33.53 s | Average time decreased by 20.5%. <details> <summary>10 local runs per version</summary> Before: ``` 37.98, 43.68, 41.10, 46.38, 41.41, 44.53, 37.53, 43.92, 45.74, 43.68 ``` After: ``` 28.66, 33.49, 40.50, 30.42, 36.30, 30.53, 35.37, 33.56, 39.28, 30.45 ``` </details> CI: https://github.com/F64116045/ozone/actions/runs/39033145603 Flaky test check: https://github.com/F64116045/ozone/actions/runs/39033245975 -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. To unsubscribe, e-mail: [email protected] For queries about this service, please contact Infrastructure at: [email protected] --------------------------------------------------------------------- To unsubscribe, e-mail: [email protected] For additional commands, e-mail: [email protected]
